You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@qpid.apache.org by rg...@apache.org on 2015/07/08 15:50:18 UTC

svn commit: r1689876 [6/6] - in /qpid/java/trunk: bdbstore/src/main/java/org/apache/qpid/server/store/berkeleydb/upgrade/ broker-plugins/amqp-0-8-protocol/src/main/java/org/apache/qpid/server/protocol/v0_8/ broker-plugins/amqp-0-8-protocol/src/test/jav...

Modified: qpid/java/trunk/systests/src/main/java/org/apache/qpid/test/utils/QpidBrokerTestCase.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/systests/src/main/java/org/apache/qpid/test/utils/QpidBrokerTestCase.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/systests/src/main/java/org/apache/qpid/test/utils/QpidBrokerTestCase.java (original)
+++ qpid/java/trunk/systests/src/main/java/org/apache/qpid/test/utils/QpidBrokerTestCase.java Wed Jul  8 13:50:16 2015
@@ -44,7 +44,7 @@ import ch.qos.logback.classic.spi.ILoggi
 import ch.qos.logback.core.Appender;
 import ch.qos.logback.core.FileAppender;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.client.BrokerDetails;
 import org.apache.qpid.client.AMQConnectionFactory;
 import org.apache.qpid.client.AMQConnectionURL;
@@ -971,7 +971,8 @@ public class QpidBrokerTestCase extends
         return con;
     }
 
-    protected Connection getClientConnection(String username, String password, String id) throws JMSException, URLSyntaxException, AMQException, NamingException
+    protected Connection getClientConnection(String username, String password, String id) throws JMSException, URLSyntaxException,
+                                                                                                 QpidException, NamingException
     {
         _logger.debug("get connection for id " + id);
         Connection con = getConnectionFactory().createConnection(username, password, id);

Modified: qpid/java/trunk/systests/src/test/java/org/apache/qpid/client/failover/FailoverBehaviourTest.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/systests/src/test/java/org/apache/qpid/client/failover/FailoverBehaviourTest.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/systests/src/test/java/org/apache/qpid/client/failover/FailoverBehaviourTest.java (original)
+++ qpid/java/trunk/systests/src/test/java/org/apache/qpid/client/failover/FailoverBehaviourTest.java Wed Jul  8 13:50:16 2015
@@ -18,7 +18,7 @@
  */
 package org.apache.qpid.client.failover;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.client.BrokerDetails;
 import org.apache.qpid.client.AMQConnection;
 import org.apache.qpid.client.AMQConnectionFactory;
@@ -1467,7 +1467,7 @@ public class FailoverBehaviourTest exten
      * @return queue browser
      * @throws JMSException
      */
-    private QueueBrowser prepareQueueBrowser(int acknowledgeMode) throws JMSException, AMQException
+    private QueueBrowser prepareQueueBrowser(int acknowledgeMode) throws JMSException, QpidException
     {
         init(acknowledgeMode, false);
         _consumer.close();

Modified: qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/failover/FailoverMethodTest.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/failover/FailoverMethodTest.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/failover/FailoverMethodTest.java (original)
+++ qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/failover/FailoverMethodTest.java Wed Jul  8 13:50:16 2015
@@ -25,7 +25,7 @@ import org.slf4j.LoggerFactory;
 
 import org.apache.qpid.AMQConnectionClosedException;
 import org.apache.qpid.AMQDisconnectedException;
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.client.AMQConnection;
 import org.apache.qpid.client.AMQConnectionURL;
 import org.apache.qpid.test.utils.QpidBrokerTestCase;
@@ -98,7 +98,7 @@ public class FailoverMethodTest extends
             // We allow 1 second for initial connection and failover logic on top of 6s of sleep.
             assertTrue("Failover took more than 11 seconds:(" + duration + ")", duration < 11000);
         }
-        catch (AMQException e)
+        catch (QpidException e)
         {
             fail(e.getMessage());
         }
@@ -148,7 +148,7 @@ public class FailoverMethodTest extends
             // We allow 3 second for initial connection and failover logic on top of 6s of sleep.
             assertTrue("Failover took more than 9 seconds:(" + duration + ")", duration < 9000);
         }
-        catch (AMQException e)
+        catch (QpidException e)
         {
             fail(e.getMessage());
         }
@@ -237,7 +237,7 @@ public class FailoverMethodTest extends
             // Occasionally it takes 1s so we have to set CONNECT_DELAY to be higher to take that in to account. 
             assertTrue("Notification of the connection failure took was : " + CONNECT_DELAY + " >:(" + duration + ")", duration < CONNECT_DELAY);
         }
-        catch (AMQException e)
+        catch (QpidException e)
         {
             fail(e.getMessage());
         }

Modified: qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/logging/ChannelLoggingTest.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/logging/ChannelLoggingTest.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/logging/ChannelLoggingTest.java (original)
+++ qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/logging/ChannelLoggingTest.java Wed Jul  8 13:50:16 2015
@@ -20,7 +20,7 @@
  */
 package org.apache.qpid.server.logging;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.client.AMQConnection;
 import org.apache.qpid.client.AMQDestination;
 import org.apache.qpid.client.AMQSession;
@@ -338,7 +338,7 @@ public class ChannelLoggingTest extends
             ((AMQSession<?,?>)session2).declareAndBind((AMQDestination) queue);
             fail("Exception not thrown");
         }
-        catch (AMQException acce)
+        catch (QpidException acce)
         {
             // pass
         }

Modified: qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/logging/DurableQueueLoggingTest.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/logging/DurableQueueLoggingTest.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/logging/DurableQueueLoggingTest.java (original)
+++ qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/logging/DurableQueueLoggingTest.java Wed Jul  8 13:50:16 2015
@@ -20,7 +20,7 @@
  */
 package org.apache.qpid.server.logging;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.client.AMQSession;
 
 import javax.jms.Connection;
@@ -193,7 +193,7 @@ public class DurableQueueLoggingTest ext
      * @throws javax.naming.NamingException
      * @throws java.io.IOException
      */
-    public void testCreateQueuePersistentPriority() throws NamingException, JMSException, IOException, AMQException
+    public void testCreateQueuePersistentPriority() throws NamingException, JMSException, IOException, QpidException
     {
         // To Create a Priority queue we need to use AMQSession specific code
         final Map<String, Object> arguments = new HashMap<String, Object>();
@@ -239,7 +239,8 @@ public class DurableQueueLoggingTest ext
      * @throws javax.naming.NamingException
      * @throws java.io.IOException
      */
-    public void testCreateQueuePersistentAutoDeletePriority() throws NamingException, JMSException, IOException, AMQException
+    public void testCreateQueuePersistentAutoDeletePriority() throws NamingException, JMSException, IOException,
+                                                                     QpidException
     {
         // To Create a Priority queue we need to use AMQSession specific code
         final Map<String, Object> arguments = new HashMap<String, Object>();

Modified: qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/logging/QueueLoggingTest.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/logging/QueueLoggingTest.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/logging/QueueLoggingTest.java (original)
+++ qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/logging/QueueLoggingTest.java Wed Jul  8 13:50:16 2015
@@ -20,7 +20,7 @@
  */
 package org.apache.qpid.server.logging;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.client.AMQSession;
 import org.apache.qpid.client.failover.FailoverException;
 import org.apache.qpid.server.logging.subjects.AbstractTestLogSubject;
@@ -79,7 +79,7 @@ public class QueueLoggingTest extends Ab
      * @throws javax.jms.JMSException
      * @throws javax.naming.NamingException
      */
-    public void testQueueDelete() throws NamingException, JMSException, IOException, FailoverException, AMQException
+    public void testQueueDelete() throws NamingException, JMSException, IOException, FailoverException, QpidException
     {
         // To force a queue Creation Event we need to create a consumer.
         Queue queue = _session.createQueue(getTestQueueName());

Modified: qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/message/MessageProtocolConversionTest.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/message/MessageProtocolConversionTest.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/message/MessageProtocolConversionTest.java (original)
+++ qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/message/MessageProtocolConversionTest.java Wed Jul  8 13:50:16 2015
@@ -20,7 +20,7 @@
  */
 package org.apache.qpid.server.message;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.configuration.ClientProperties;
 import org.apache.qpid.test.utils.QpidBrokerTestCase;
 
@@ -58,18 +58,18 @@ public class MessageProtocolConversionTe
         _connection_0_9_1 = getConnection();
     }
 
-    public void test0_9_1_to_0_10_conversion() throws JMSException, AMQException
+    public void test0_9_1_to_0_10_conversion() throws JMSException, QpidException
     {
         doConversionTests(_connection_0_9_1, _connection_0_10);
     }
 
-    public void test_0_10_to_0_9_1_conversion() throws JMSException, AMQException
+    public void test_0_10_to_0_9_1_conversion() throws JMSException, QpidException
     {
 
         doConversionTests(_connection_0_10, _connection_0_9_1);
     }
 
-    private void doConversionTests(Connection producerConn, Connection consumerConn) throws JMSException, AMQException
+    private void doConversionTests(Connection producerConn, Connection consumerConn) throws JMSException, QpidException
     {
         Session producerSession = producerConn.createSession(false, Session.AUTO_ACKNOWLEDGE);
         Session consumerSession = consumerConn.createSession(false, Session.AUTO_ACKNOWLEDGE);

Modified: qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/ArrivalTimeFilterTest.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/ArrivalTimeFilterTest.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/ArrivalTimeFilterTest.java (original)
+++ qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/ArrivalTimeFilterTest.java Wed Jul  8 13:50:16 2015
@@ -29,7 +29,7 @@ import javax.jms.Queue;
 import javax.jms.Session;
 import javax.jms.TextMessage;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.client.AMQDestination;
 import org.apache.qpid.client.AMQSession;
 import org.apache.qpid.test.utils.QpidBrokerTestCase;
@@ -53,7 +53,7 @@ public class ArrivalTimeFilterTest exten
     }
 
 
-    public void testArrivalTime0() throws AMQException, JMSException, InterruptedException
+    public void testArrivalTime0() throws QpidException, JMSException, InterruptedException
     {
         createDestinationWithFilter(0);
         final MessageProducer prod = _session.createProducer(_queue);
@@ -74,7 +74,7 @@ public class ArrivalTimeFilterTest exten
     }
 
 
-    public void testArrivalTime1000() throws AMQException, JMSException, InterruptedException
+    public void testArrivalTime1000() throws QpidException, JMSException, InterruptedException
     {
         createDestinationWithFilter(1000);
         final MessageProducer prod = _session.createProducer(_queue);
@@ -94,7 +94,7 @@ public class ArrivalTimeFilterTest exten
         assertNotNull("Message should be received", receivedMsg);
     }
 
-    private void createDestinationWithFilter(final int period) throws AMQException, JMSException
+    private void createDestinationWithFilter(final int period) throws QpidException, JMSException
     {
         ((AMQSession<?,?>) _session).createQueue(_queueName, false, true, false, null);
         Queue queue = new org.apache.qpid.client.AMQQueue("amq.direct", _queueName);

Modified: qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/DefaultFiltersTest.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/DefaultFiltersTest.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/DefaultFiltersTest.java (original)
+++ qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/DefaultFiltersTest.java Wed Jul  8 13:50:16 2015
@@ -32,7 +32,7 @@ import javax.jms.Queue;
 import javax.jms.Session;
 import javax.jms.TextMessage;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.client.AMQDestination;
 import org.apache.qpid.client.AMQSession;
 import org.apache.qpid.test.utils.QpidBrokerTestCase;
@@ -55,7 +55,7 @@ public class DefaultFiltersTest extends
         _connection.start();
     }
 
-    private void createQueueWithDefaultFilter(String selector) throws AMQException
+    private void createQueueWithDefaultFilter(String selector) throws QpidException
     {
         final Map<String,Object> arguments = new HashMap<>();
         selector = selector.replace("\\", "\\\\");
@@ -67,7 +67,7 @@ public class DefaultFiltersTest extends
         ((AMQSession<?,?>) _session).declareAndBind((AMQDestination)_queue);
     }
 
-    public void testDefaultFilterIsApplied() throws AMQException, JMSException
+    public void testDefaultFilterIsApplied() throws QpidException, JMSException
     {
         createQueueWithDefaultFilter("foo = 1");
         final MessageProducer prod = _session.createProducer(_queue);
@@ -89,7 +89,7 @@ public class DefaultFiltersTest extends
     }
 
 
-    public void testDefaultFilterIsOverridden() throws AMQException, JMSException
+    public void testDefaultFilterIsOverridden() throws QpidException, JMSException
     {
         createQueueWithDefaultFilter("foo = 1");
         final MessageProducer prod = _session.createProducer(_queue);

Modified: qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/EnsureNondestructiveConsumersTest.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/EnsureNondestructiveConsumersTest.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/EnsureNondestructiveConsumersTest.java (original)
+++ qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/EnsureNondestructiveConsumersTest.java Wed Jul  8 13:50:16 2015
@@ -32,7 +32,7 @@ import javax.jms.Queue;
 import javax.jms.Session;
 import javax.jms.TextMessage;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.client.AMQDestination;
 import org.apache.qpid.client.AMQSession;
 import org.apache.qpid.test.utils.QpidBrokerTestCase;
@@ -55,7 +55,8 @@ public class EnsureNondestructiveConsume
         _connection.start();
     }
 
-    private void createQueueEnsureNondestructiveConsumerOption(boolean ensureNonDestructiveConsumer) throws AMQException
+    private void createQueueEnsureNondestructiveConsumerOption(boolean ensureNonDestructiveConsumer) throws
+                                                                                                     QpidException
     {
         final Map<String,Object> arguments = new HashMap<>();
 
@@ -65,7 +66,7 @@ public class EnsureNondestructiveConsume
         ((AMQSession<?,?>) _session).declareAndBind((AMQDestination)_queue);
     }
 
-    public void testEnsureNondestructiveConsumers() throws AMQException, JMSException
+    public void testEnsureNondestructiveConsumers() throws QpidException, JMSException
     {
         createQueueEnsureNondestructiveConsumerOption(true);
         final MessageProducer prod = _session.createProducer(_queue);

Modified: qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/LastValueQueueTest.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/LastValueQueueTest.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/LastValueQueueTest.java (original)
+++ qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/LastValueQueueTest.java Wed Jul  8 13:50:16 2015
@@ -40,7 +40,7 @@ import javax.jms.Session;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.client.AMQConnection;
 import org.apache.qpid.client.AMQDestination;
 import org.apache.qpid.client.AMQQueue;
@@ -549,7 +549,7 @@ public class LastValueQueueTest extends
         }
     }
 
-    private void createConflationQueue(Session session) throws AMQException
+    private void createConflationQueue(Session session) throws QpidException
     {
         final Map<String,Object> arguments = new HashMap<String, Object>();
         arguments.put("qpid.last_value_queue_key",KEY_PROPERTY);

Modified: qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/MessageGroupQueueTest.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/MessageGroupQueueTest.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/MessageGroupQueueTest.java (original)
+++ qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/MessageGroupQueueTest.java Wed Jul  8 13:50:16 2015
@@ -35,7 +35,7 @@ import javax.jms.MessageProducer;
 import javax.jms.Queue;
 import javax.jms.Session;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.client.AMQConnection;
 import org.apache.qpid.client.AMQDestination;
 import org.apache.qpid.client.AMQSession;
@@ -112,7 +112,7 @@ public class MessageGroupQueueTest exten
      *  c1 ack --->
      *
      */
-    private void simpleGroupAssignment(boolean sharedGroups) throws AMQException, JMSException
+    private void simpleGroupAssignment(boolean sharedGroups) throws QpidException, JMSException
     {
         final Map<String,Object> arguments = new HashMap<String, Object>();
         arguments.put(QueueArgumentsConverter.QPID_GROUP_HEADER_KEY,"group");
@@ -202,7 +202,7 @@ public class MessageGroupQueueTest exten
      * requires c2 to go "backwards" in the queue).
      *
      **/
-    private void consumerCloseGroupAssignment(boolean sharedGroups) throws AMQException, JMSException
+    private void consumerCloseGroupAssignment(boolean sharedGroups) throws QpidException, JMSException
     {
         final Map<String,Object> arguments = new HashMap<String, Object>();
         arguments.put(QueueArgumentsConverter.QPID_GROUP_HEADER_KEY,"group");
@@ -301,7 +301,7 @@ public class MessageGroupQueueTest exten
      * requires c2 to go "backwards" in the queue). The first such message should be marked as redelivered
      *
      */
-    private void consumerCloseWithRelease(boolean sharedGroups) throws AMQException, JMSException
+    private void consumerCloseWithRelease(boolean sharedGroups) throws QpidException, JMSException
     {
         final Map<String,Object> arguments = new HashMap<String, Object>();
         arguments.put(QueueArgumentsConverter.QPID_GROUP_HEADER_KEY,"group");
@@ -383,17 +383,17 @@ public class MessageGroupQueueTest exten
         assertNull(consumer2.receive(1000));
     }
 
-    public void testGroupAssignmentSurvivesEmpty() throws JMSException, AMQException
+    public void testGroupAssignmentSurvivesEmpty() throws JMSException, QpidException
     {
         groupAssignmentOnEmpty(false);
     }
 
-    public void testSharedGroupAssignmentDoesNotSurviveEmpty() throws JMSException, AMQException
+    public void testSharedGroupAssignmentDoesNotSurviveEmpty() throws JMSException, QpidException
     {
         groupAssignmentOnEmpty(true);
     }
 
-    private void groupAssignmentOnEmpty(boolean sharedGroups) throws AMQException, JMSException
+    private void groupAssignmentOnEmpty(boolean sharedGroups) throws QpidException, JMSException
     {
         final Map<String,Object> arguments = new HashMap<String, Object>();
         arguments.put(QueueArgumentsConverter.QPID_GROUP_HEADER_KEY,"group");

Modified: qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/ModelTest.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/ModelTest.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/PriorityQueueTest.java (original)
+++ qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/PriorityQueueTest.java Wed Jul  8 13:50:16 2015
@@ -38,7 +38,7 @@ import javax.naming.NamingException;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.client.AMQConnection;
 import org.apache.qpid.client.AMQDestination;
 import org.apache.qpid.client.AMQSession;
@@ -83,7 +83,7 @@ public class PriorityQueueTest extends Q
         super.tearDown();
     }
 
-    public void testPriority() throws JMSException, NamingException, AMQException
+    public void testPriority() throws JMSException, NamingException, QpidException
     {
         final Map<String,Object> arguments = new HashMap<String, Object>();
         arguments.put("x-qpid-priorities",10);
@@ -124,7 +124,7 @@ public class PriorityQueueTest extends Q
         assertEquals("Incorrect number of message received", 50, receivedCount);
     }
 
-    public void testOddOrdering() throws AMQException, JMSException
+    public void testOddOrdering() throws QpidException, JMSException
     {
         final Map<String,Object> arguments = new HashMap<String, Object>();
         arguments.put("x-qpid-priorities",3);

Modified: qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/ProducerFlowControlTest.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/ProducerFlowControlTest.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/ProducerFlowControlTest.java (original)
+++ qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/ProducerFlowControlTest.java Wed Jul  8 13:50:16 2015
@@ -40,7 +40,7 @@ import javax.jms.Session;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.client.AMQDestination;
 import org.apache.qpid.client.AMQSession;
 import org.apache.qpid.management.common.mbeans.ManagedQueue;
@@ -428,7 +428,7 @@ public class ProducerFlowControlTest ext
             {
                 ((AMQSession<?,?>)producerSession).sync();
             }
-            catch (AMQException e)
+            catch (QpidException e)
             {
                 _logger.error("Error performing sync", e);
                 throw new RuntimeException(e);

Modified: qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/QueueBindTest.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/QueueBindTest.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/QueueBindTest.java (original)
+++ qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/QueueBindTest.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ import javax.jms.Message;
 import javax.jms.MessageConsumer;
 import javax.jms.Session;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.client.AMQDestination;
 import org.apache.qpid.client.AMQQueue;
 import org.apache.qpid.client.AMQSession;
@@ -67,7 +67,7 @@ public class QueueBindTest extends QpidB
 
     }
 
-    private void runTestForTopicExchange(AMQDestination destination) throws AMQException, JMSException, Exception
+    private void runTestForTopicExchange(AMQDestination destination) throws QpidException, JMSException, Exception
     {
         // binding queue with empty arguments
         _session.declareAndBind(destination,Collections.<String, Object>emptyMap());
@@ -99,7 +99,7 @@ public class QueueBindTest extends QpidB
         }
     }
 
-    private void runTestForNonTopicExhange(AMQQueue destination) throws AMQException, Exception, JMSException
+    private void runTestForNonTopicExhange(AMQQueue destination) throws QpidException, Exception, JMSException
     {
         // binding queue with empty arguments
         _session.declareAndBind(destination,

Modified: qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/QueueDepthWithSelectorTest.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/QueueDepthWithSelectorTest.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/QueueDepthWithSelectorTest.java (original)
+++ qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/QueueDepthWithSelectorTest.java Wed Jul  8 13:50:16 2015
@@ -21,7 +21,7 @@
 
 package org.apache.qpid.server.queue;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.client.AMQDestination;
 import org.apache.qpid.client.AMQSession;
 import org.apache.qpid.test.utils.QpidBrokerTestCase;
@@ -117,7 +117,7 @@ public class QueueDepthWithSelectorTest
             
             connection.close();
         }
-        catch (AMQException e)
+        catch (QpidException e)
         {
             fail(e.getMessage());
         }

Modified: qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/SortedQueueTest.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/SortedQueueTest.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/SortedQueueTest.java (original)
+++ qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/SortedQueueTest.java Wed Jul  8 13:50:16 2015
@@ -39,7 +39,7 @@ import javax.naming.NamingException;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.client.AMQDestination;
 import org.apache.qpid.client.AMQQueue;
 import org.apache.qpid.client.AMQSession;
@@ -79,7 +79,7 @@ public class SortedQueueTest extends Qpi
         super.tearDown();
     }
 
-    public void testSortOrder() throws JMSException, NamingException, AMQException
+    public void testSortOrder() throws JMSException, NamingException, QpidException
     {
         final Queue queue = createQueue();
         final MessageProducer producer = _producerSession.createProducer(queue);
@@ -111,23 +111,23 @@ public class SortedQueueTest extends Qpi
         assertEquals("Incorrect number of messages received", VALUES.length, messageCount);
     }
 
-    public void testAutoAckSortedQueue() throws JMSException, NamingException, AMQException
+    public void testAutoAckSortedQueue() throws JMSException, NamingException, QpidException
     {
         runThroughSortedQueueForSessionMode(Session.AUTO_ACKNOWLEDGE);
     }
 
-    public void testTransactedSortedQueue() throws JMSException, NamingException, AMQException
+    public void testTransactedSortedQueue() throws JMSException, NamingException, QpidException
     {
         runThroughSortedQueueForSessionMode(Session.SESSION_TRANSACTED);
     }
 
-    public void testClientAckSortedQueue() throws JMSException, NamingException, AMQException
+    public void testClientAckSortedQueue() throws JMSException, NamingException, QpidException
     {
         runThroughSortedQueueForSessionMode(Session.CLIENT_ACKNOWLEDGE);
     }
 
     private void runThroughSortedQueueForSessionMode(final int sessionMode) throws JMSException, NamingException,
-                    AMQException
+                                                                                   QpidException
     {
         final Queue queue = createQueue();
         final MessageProducer producer = _producerSession.createProducer(queue);
@@ -158,7 +158,7 @@ public class SortedQueueTest extends Qpi
         producer.close();
     }
 
-    public void testSortedQueueWithAscendingSortedKeys() throws JMSException, NamingException, AMQException
+    public void testSortedQueueWithAscendingSortedKeys() throws JMSException, NamingException, QpidException
     {
         final Queue queue = createQueue();
         final MessageProducer producer = _producerSession.createProducer(queue);
@@ -195,7 +195,7 @@ public class SortedQueueTest extends Qpi
         return isBrokerStorePersistent() ? 50000L: 5000L;
     }
 
-    public void testSortOrderWithNonUniqueKeys() throws JMSException, NamingException, AMQException
+    public void testSortOrderWithNonUniqueKeys() throws JMSException, NamingException, QpidException
     {
         final Queue queue = createQueue();
         final MessageProducer producer = _producerSession.createProducer(queue);
@@ -229,7 +229,7 @@ public class SortedQueueTest extends Qpi
         assertEquals("Incorrect number of messages received", 200, messageCount);
     }
 
-    public void testSortOrderWithUniqueKeySubset() throws JMSException, NamingException, AMQException
+    public void testSortOrderWithUniqueKeySubset() throws JMSException, NamingException, QpidException
     {
         final Queue queue = createQueue();
         final MessageProducer producer = _producerSession.createProducer(queue);
@@ -263,7 +263,7 @@ public class SortedQueueTest extends Qpi
         assertEquals("Incorrect number of messages received", 100, messageCount);
     }
 
-    public void testGetNextWithAck() throws JMSException, NamingException, AMQException
+    public void testGetNextWithAck() throws JMSException, NamingException, QpidException
     {
         Queue _queue = createQueue();
         MessageProducer producer = _producerSession.createProducer(_queue);
@@ -334,7 +334,7 @@ public class SortedQueueTest extends Qpi
         }
     }
 
-    private Queue createQueue() throws AMQException, JMSException
+    private Queue createQueue() throws QpidException, JMSException
     {
         final Map<String, Object> arguments = new HashMap<String, Object>();
         arguments.put(QueueArgumentsConverter.QPID_QUEUE_SORT_KEY, TEST_SORT_KEY);

Modified: qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/security/acl/ExhaustiveACLTest.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/security/acl/ExhaustiveACLTest.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/security/acl/ExhaustiveACLTest.java (original)
+++ qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/security/acl/ExhaustiveACLTest.java Wed Jul  8 13:50:16 2015
@@ -23,6 +23,7 @@ import javax.jms.MessageConsumer;
 import javax.jms.Queue;
 import javax.jms.Session;
 
+import org.apache.qpid.QpidException;
 import org.apache.qpid.AMQException;
 import org.apache.qpid.client.AMQSession;
 import org.apache.qpid.configuration.ClientProperties;
@@ -65,7 +66,7 @@ public class ExhaustiveACLTest extends A
 		{
 			createQueue(vhost, user, name, autoDelete, durable);
 		}
-		catch (AMQException e)
+		catch (QpidException e)
 		{
 			fail(String.format("Create queue should have worked for \"%s\" for user %s@%s, autoDelete=%s, durable=%s",
                                name, user, vhost, Boolean.toString(autoDelete), Boolean.toString(durable)));

Modified: qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/security/acl/ExternalACLTest.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/security/acl/ExternalACLTest.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/security/acl/ExternalACLTest.java (original)
+++ qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/security/acl/ExternalACLTest.java Wed Jul  8 13:50:16 2015
@@ -31,6 +31,7 @@ import javax.jms.Topic;
 import javax.jms.TopicSubscriber;
 import javax.naming.NamingException;
 
+import org.apache.qpid.QpidException;
 import org.apache.qpid.AMQException;
 import org.apache.qpid.client.AMQDestination;
 import org.apache.qpid.client.AMQSession;
@@ -82,7 +83,7 @@ public class ExternalACLTest extends Abs
         assertNotNull("There was no linked exception", linkedException);
         Throwable cause = linkedException.getCause();
         assertNotNull("Cause was null", cause);
-        assertTrue("Wrong linked exception type", cause instanceof AMQException);
+        assertTrue("Wrong linked exception type", cause instanceof QpidException);
         AMQConstant errorCode = isBroker010() ? AMQConstant.CONNECTION_FORCED : AMQConstant.ACCESS_REFUSED;
         assertEquals("Incorrect error code received", errorCode, ((AMQException) cause).getErrorCode());
     }
@@ -122,7 +123,7 @@ public class ExternalACLTest extends Abs
                      "ACL DENY-LOG  guest CREATE QUEUE virtualhost_name='test'");
     }
 
-    public void testClientCreateVirtualHostQueue() throws NamingException, JMSException, AMQException, Exception
+    public void testClientCreateVirtualHostQueue() throws NamingException, JMSException, QpidException, Exception
     {
         Connection conn = getConnection("test", "client", "guest");
         Session sess = conn.createSession(false, Session.AUTO_ACKNOWLEDGE);
@@ -320,7 +321,7 @@ public class ExternalACLTest extends Abs
                      "ACL ALLOW-LOG client CREATE QUEUE name=\"ValidQueue\"");
     }
 
-    public void testClientCreateNamedQueueFailure() throws NamingException, JMSException, AMQException, Exception
+    public void testClientCreateNamedQueueFailure() throws NamingException, JMSException, QpidException, Exception
     {
         Connection conn = getConnection("test", "client", "guest");
         Session sess = conn.createSession(false, Session.AUTO_ACKNOWLEDGE);

Modified: qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/security/auth/manager/MultipleAuthenticationManagersTest.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/security/auth/manager/MultipleAuthenticationManagersTest.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/security/auth/manager/MultipleAuthenticationManagersTest.java (original)
+++ qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/security/auth/manager/MultipleAuthenticationManagersTest.java Wed Jul  8 13:50:16 2015
@@ -32,7 +32,7 @@ import java.util.Map;
 import javax.jms.Connection;
 import javax.jms.JMSException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.client.AMQConnection;
 import org.apache.qpid.server.model.AuthenticationProvider;
 import org.apache.qpid.server.model.DefaultVirtualHostAlias;
@@ -132,7 +132,7 @@ public class MultipleAuthenticationManag
             Connection conn = getAnonymousConnection();
             fail("Should not be able to create anonymous connection to the standard port");
         }
-        catch(AMQException e)
+        catch(QpidException e)
         {
             // pass
         }

Modified: qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/stats/StatisticsReportingTest.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/stats/StatisticsReportingTest.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/stats/StatisticsReportingTest.java (original)
+++ qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/stats/StatisticsReportingTest.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ import javax.jms.MessageProducer;
 import javax.jms.Session;
 import javax.jms.TextMessage;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.client.AMQConnection;
 import org.apache.qpid.client.AMQDestination;
 import org.apache.qpid.client.AMQQueue;
@@ -169,7 +169,7 @@ public class StatisticsReportingTest ext
         session.close();
     }
 
-    private void createQueue(Session session) throws AMQException, JMSException
+    private void createQueue(Session session) throws QpidException, JMSException
     {
         _queue = new AMQQueue(ExchangeDefaults.DIRECT_EXCHANGE_NAME, _queueName);
         if (!((AMQSession<?,?>) session).isQueueBound((AMQDestination) _queue))

Modified: qpid/java/trunk/systests/src/test/java/org/apache/qpid/test/client/QueueBrowserAutoAckTest.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/systests/src/test/java/org/apache/qpid/test/client/QueueBrowserAutoAckTest.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/systests/src/test/java/org/apache/qpid/test/client/QueueBrowserAutoAckTest.java (original)
+++ qpid/java/trunk/systests/src/test/java/org/apache/qpid/test/client/QueueBrowserAutoAckTest.java Wed Jul  8 13:50:16 2015
@@ -31,7 +31,7 @@ import javax.jms.QueueBrowser;
 import javax.jms.Session;
 import javax.jms.TextMessage;
 import javax.naming.NamingException;
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.client.AMQDestination;
 import org.apache.qpid.client.AMQSession;
 import org.apache.qpid.test.utils.QpidBrokerTestCase;
@@ -141,7 +141,7 @@ public class QueueBrowserAutoAckTest ext
         {
             queueDepth = ((AMQSession) _clientSession).getQueueDepth((AMQDestination) _queue);
         }
-        catch (AMQException e)
+        catch (QpidException e)
         {
         }
 

Modified: qpid/java/trunk/systests/src/test/java/org/apache/qpid/test/unit/client/DynamicQueueExchangeCreateTest.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/systests/src/test/java/org/apache/qpid/test/unit/client/DynamicQueueExchangeCreateTest.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/systests/src/test/java/org/apache/qpid/test/unit/client/DynamicQueueExchangeCreateTest.java (original)
+++ qpid/java/trunk/systests/src/test/java/org/apache/qpid/test/unit/client/DynamicQueueExchangeCreateTest.java Wed Jul  8 13:50:16 2015
@@ -241,7 +241,7 @@ public class DynamicQueueExchangeCreateT
     {
         Exception linked = original.getLinkedException();
         assertNotNull("Linked exception should have been set", linked);
-        assertTrue("Linked exception should be an AMQException", linked instanceof AMQException);
+        assertTrue("Linked exception should be an AMQProtocolException", linked instanceof AMQException);
         assertEquals("Error code should be " + code.getCode(), code, ((AMQException) linked).getErrorCode());
     }
 

Modified: qpid/java/trunk/systests/src/test/java/org/apache/qpid/test/unit/client/MaxDeliveryCountTest.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/systests/src/test/java/org/apache/qpid/test/unit/client/MaxDeliveryCountTest.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/systests/src/test/java/org/apache/qpid/test/unit/client/MaxDeliveryCountTest.java (original)
+++ qpid/java/trunk/systests/src/test/java/org/apache/qpid/test/unit/client/MaxDeliveryCountTest.java Wed Jul  8 13:50:16 2015
@@ -40,7 +40,7 @@ import javax.jms.Topic;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.client.AMQDestination;
 import org.apache.qpid.client.AMQQueue;
 import org.apache.qpid.client.AMQSession;
@@ -301,7 +301,7 @@ public class MaxDeliveryCountTest extend
 
     }
 
-    private void verifyDLQdepth(int expected, Session clientSession, boolean durableSub) throws AMQException
+    private void verifyDLQdepth(int expected, Session clientSession, boolean durableSub) throws QpidException
     {
         AMQDestination checkQueueDLQ;
         if(durableSub)
@@ -533,7 +533,8 @@ public class MaxDeliveryCountTest extend
     }
 
     private void doSynchronousTest(final Session session, final MessageConsumer consumer, final int deliveryMode, final int maxDeliveryCount,
-            final int expectedTotalNumberOfDeliveries, final List<Integer> redeliverMsgs) throws JMSException, AMQException, InterruptedException
+            final int expectedTotalNumberOfDeliveries, final List<Integer> redeliverMsgs) throws JMSException,
+                                                                                                 QpidException, InterruptedException
    {
         if(deliveryMode == Session.AUTO_ACKNOWLEDGE
                 || deliveryMode == Session.DUPS_OK_ACKNOWLEDGE

Modified: qpid/java/trunk/systests/src/test/java/org/apache/qpid/test/unit/client/connection/ConnectionTest.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/systests/src/test/java/org/apache/qpid/test/unit/client/connection/ConnectionTest.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/systests/src/test/java/org/apache/qpid/test/unit/client/connection/ConnectionTest.java (original)
+++ qpid/java/trunk/systests/src/test/java/org/apache/qpid/test/unit/client/connection/ConnectionTest.java Wed Jul  8 13:50:16 2015
@@ -25,7 +25,7 @@ import javax.jms.QueueSession;
 import javax.jms.TopicSession;
 
 import org.apache.qpid.AMQConnectionFailureException;
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.AMQUnresolvedAddressException;
 import org.apache.qpid.client.BrokerDetails;
 import org.apache.qpid.client.AMQConnection;
@@ -141,7 +141,7 @@ public class ConnectionTest extends Qpid
         catch (AMQConnectionFailureException amqe)
         {
             assertNotNull("No cause set:" + amqe.getMessage(), amqe.getCause());
-            assertTrue("Exception was wrong type", amqe.getCause() instanceof AMQException);
+            assertTrue("Exception was wrong type", amqe.getCause() instanceof QpidException);
         }
         finally
         {
@@ -160,11 +160,11 @@ public class ConnectionTest extends Qpid
             conn = new AMQConnection("amqp://guest:guest@clientid/testpath?brokerlist='" + _broker_NotRunning + "?retries='0''");
             fail("Connection should not be established");
         }
-        catch (AMQException amqe)
+        catch (QpidException amqe)
         {
             if (!(amqe instanceof AMQConnectionFailureException))
             {
-                fail("Correct exception not thrown. Excpected 'AMQConnectionException' got: " + amqe);
+                fail("Correct exception not thrown. Expected 'AMQConnectionException' got: " + amqe);
             }
         }
         finally
@@ -185,7 +185,7 @@ public class ConnectionTest extends Qpid
             conn = new AMQConnection("amqp://guest:guest@clientid/testpath?brokerlist='" + _broker_BadDNS + "?retries='0''");
             fail("Connection should not be established");
         }
-        catch (AMQException amqe)
+        catch (QpidException amqe)
         {
             if (!(amqe instanceof AMQUnresolvedAddressException))
             {
@@ -212,7 +212,7 @@ public class ConnectionTest extends Qpid
             conn = new AMQConnection("amqp://guest:guest@clientid/rubbishhost?brokerlist='" + broker + "'");
             fail("Connection should not be established");
         }
-        catch (AMQException amqe)
+        catch (QpidException amqe)
         {
             if (!(amqe instanceof AMQConnectionFailureException))
             {

Modified: qpid/java/trunk/systests/src/test/java/org/apache/qpid/test/unit/topic/TopicSessionTest.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/systests/src/test/java/org/apache/qpid/test/unit/topic/TopicSessionTest.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/systests/src/test/java/org/apache/qpid/test/unit/topic/TopicSessionTest.java (original)
+++ qpid/java/trunk/systests/src/test/java/org/apache/qpid/test/unit/topic/TopicSessionTest.java Wed Jul  8 13:50:16 2015
@@ -22,7 +22,7 @@ package org.apache.qpid.test.unit.topic;
 
 import javax.jms.JMSException;
 import javax.naming.NamingException;
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.client.AMQConnection;
 import org.apache.qpid.client.AMQQueue;
 import org.apache.qpid.client.AMQSession;
@@ -265,7 +265,7 @@ public class TopicSessionTest extends Qp
 
 
     private void noLocalTest(AMQConnection con, AMQTopic topic)
-            throws JMSException, URLSyntaxException, AMQException, NamingException
+            throws JMSException, URLSyntaxException, QpidException, NamingException
     {
         TopicSession session1 = con.createTopicSession(true, AMQSession.AUTO_ACKNOWLEDGE);
         TopicSubscriber noLocal = session1.createSubscriber(topic,  "", true);



---------------------------------------------------------------------
To unsubscribe, e-mail: commits-unsubscribe@qpid.apache.org
For additional commands, e-mail: commits-help@qpid.apache.org
--- qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/ModelTest.java (original)
+++ qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/ModelTest.java Wed Jul  8 13:50:16 2015
@@ -20,7 +20,7 @@
  */
 package org.apache.qpid.server.queue;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.client.AMQSession;
 import org.apache.qpid.management.common.mbeans.ManagedBroker;
 import org.apache.qpid.management.common.mbeans.ManagedQueue;
@@ -271,7 +271,7 @@ public class ModelTest extends QpidBroke
      * @param autoDelete boolean if the queue is an autoDelete queue
      * @param exclusive  boolean if the queue is exclusive
      *
      * @throws AMQException if there is a problem with the createQueue call
      * @throws JMException  if there is a problem with the JMX validatation
      * @throws IOException  if there is a problem with the JMX connection
      * @throws JMSException if there is a problem creating the JMS Session
@@ -281,7 +281,7 @@ public class ModelTest extends QpidBroke
                                                 boolean durable,
                                                 boolean autoDelete,
                                                 boolean exclusive)
-            throws AMQException, JMException, IOException, JMSException
+            throws QpidException, JMException, IOException, JMSException
     {
         AMQSession session = (AMQSession) connection.createSession(false,
                                                                    Session.AUTO_ACKNOWLEDGE);
@@ -271,7 +271,7 @@ public class ModelTest extends QpidBroke
      * @param exclusive  boolean if the queue is exclusive
      *
-     * @throws AMQException if there is a problem with the createQueue call
+     * @throws QpidException if there is a problem with the createQueue call
      * @throws JMException  if there is a problem with the JMX validatation
      * @throws IOException  if there is a problem with the JMX connection

Modified: qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/PriorityQueueTest.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/systests/src/test/java/org/apache/qpid/server/queue/PriorityQueueTest.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================